@@ -1445,8 +1445,8 @@ metamean <- function(n, mean, sd, studlab,
     ##
     res$event.e.w <- NULL
     res$event.c.w <- NULL
-    res$event.w <- NULL
-    res$n.w <- NULL
+    res$n.e.w <- NULL
+    res$n.c.w <- NULL
     res$time.e.w <- NULL
     res$time.c.w <- NULL
   }
